/*******************************************************************************
*************************keySTREAM Trusted Agent ("KTA")************************

* (c) 2023-2024 Nagravision Sàrl

* Subject to your compliance with these terms, you may use the Nagravision Sàrl
* Software and any derivatives exclusively with Nagravision's products. It is your
* responsibility to comply with third party license terms applicable to your
* use of third party software (including open source software) that may accompany
* Nagravision Software.

* Redistribution of this Nagravision Software in source or binary form is allowed
* and must include the above terms of use and the following disclaimer with the
* distribution and accompanying materials.

* THIS SOFTWARE IS SUPPLIED BY NAGRAVISION "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED WARRANTIES OF
* NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A PARTICULAR PURPOSE. IN NO
* EVENT WILL NAGRAVISION BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE, INCIDENTAL
* OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO
* THE SOFTWARE, HOWEVER CAUSED, EVEN IF NAGRAVISION HAS BEEN ADVISED OF THE
* POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWED BY LAW,
* NAGRAVISION 'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
* SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID DIRECTLY
* TO NAGRAVISION FOR THIS SOFTWARE.
********************************************************************************/
/** \brief  Crypto config for Microchip.
 *
 *  \author Kudelski IoT
 *
 *  \date 2023/06/12
 *
 *  \file cryptoConfig.h
 ******************************************************************************/

/**
 * @brief Microchip crypto configuration.
 */

#ifndef CRYPTOCONFIG_H
#define CRYPTOCONFIG_H

/* -------------------------------------------------------------------------- */
/* IMPORTS                                                                    */
/* -------------------------------------------------------------------------- */

/* -------------------------------------------------------------------------- */
/* CONSTANTS, TYPES, ENUM                                                     */
/* -------------------------------------------------------------------------- */

/** @brief Server Dos PK. */
#define C_KTA__KS_S_DOS_PK {0xEE, 0x66, 0x25, 0x51, 0xCF, 0xA1, 0x09, 0xAD, \
    0xCF, 0xC9, 0x85, 0xC6, 0xF4, 0x0F, 0xBB, 0x20, \
    0xB7, 0x25, 0x0B, 0x7D, 0x19, 0x07, 0x38, 0xD1, \
    0x50, 0x28, 0xF3, 0x8F, 0xA9, 0xB0, 0xCD, 0x04, \
    0xEA, 0xBE, 0x25, 0x46, 0x12, 0x28, 0x55, 0x8A, \
    0x5A, 0x17, 0x26, 0x40, 0x8D, 0x4E, 0xCE, 0x39, \
    0x6B, 0x27, 0x37, 0x7F, 0xC1, 0x07, 0xDF, 0x5C, \
    0x42, 0xAE, 0xA1, 0x92, 0x3C, 0xFC, 0x0E, 0x0F  \
  }

/** @brief Server Dos PK size. */
#define C_KTA__KS_S_DOS_PK_SIZE                      (64u)

/** @brief Activation key fixed info. */
#define C_KTA__ACT_KEY_FIXED_INFO {0x31, 0xde, 0xca, 0xd8, 0x3b, 0x21, 0x1c, 0x12, \
    0x69, 0xa8, 0xa9, 0x84, 0x28, 0x8c, 0xa6, 0x53, \
    0xbf, 0x98, 0xc3, 0x0d, 0x59  \
  }

/** @brief Activation key fixed info size. */
#define C_KTA__ACT_KEY_FIXED_INFO_SIZE               (21u)

/** @brief Input data for activation enc key. */
#define C_KTA__ACT_L2_ENC_INPUT_DATA {0xa9, 0x32, 0x30, 0x31, 0x38, 0x4e, 0x61, 0x67, \
    0x72, 0x61, 0x76, 0x69, 0x73, 0x69, 0x6f, 0x6e, \
    0x00, 0x4c, 0x31, 0x4b, 0x65, 0x79, 0x47, 0x65, \
    0x6e, 0x53, 0x75, 0x62, 0x4b, 0x65, 0x79, 0x31, \
    0x47, 0x43, 0x9d, 0xe8, 0x5e, 0x3a, 0x95, 0x04, \
    0x3d, 0xf3, 0x21, 0xb0, 0xf5, 0x4a, 0xd0, 0x30, \
    0x00, 0x32, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, \
    0x00, 0x00, 0x01, 0x00  \
  }

/** @brief Activation enc key size. */
#define C_KTA__ACT_L2_ENC_INPUT_DATA_SIZE            (60u)

/** @brief Input data for activation auth key. */
#define C_KTA__ACT_L2_AUTH_INPUT_DATA {0xa9, 0x32, 0x30, 0x31, 0x38, 0x4e, 0x61, 0x67, \
    0x72, 0x61, 0x76, 0x69, 0x73, 0x69, 0x6f, 0x6e, \
    0x00, 0x4c, 0x31, 0x4b, 0x65, 0x79, 0x47, 0x65, \
    0x6e, 0x53, 0x75, 0x62, 0x4b, 0x65, 0x79, 0xa7, \
    0x07, 0x0c, 0x3f, 0x25, 0x77, 0x25, 0xbc, 0xf1, \
    0x2f, 0x21, 0x42, 0x5f, 0xea, 0xca, 0x6e, 0x30, \
    0x06, 0x32, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, \
    0x00, 0x00, 0x01, 0x00  \
  }

/** @brief Activation auth key size. */
#define C_KTA__ACT_L2_AUTH_INPUT_DATA_SIZE           (60u)

/** @brief Server PK. */
#define C_KTA__KS_S_PK {0x1D, 0x4F, 0x54, 0x35, 0x1C, 0xF3, 0xFE, 0x55, \
    0x74, 0x04, 0x87, 0x6D, 0xF3, 0x9D, 0xFD, 0x47, \
    0x39, 0xAF, 0x75, 0x8C, 0xCD, 0xFF, 0x94, 0x51, \
    0x03, 0x7A, 0xCC, 0x83, 0x54, 0x1B, 0x74, 0xA3, \
    0xE1, 0x09, 0x8A, 0x1A, 0xC4, 0x3C, 0xC8, 0x55, \
    0xE7, 0x5F, 0x82, 0xA0, 0x78, 0x0F, 0xB9, 0xF7, \
    0x5D, 0xF3, 0xA9, 0x21, 0x42, 0x65, 0x57, 0x2A, \
    0x92, 0x2F, 0x0F, 0xE3, 0x7B, 0x11, 0x51, 0xF4  \
  }

/** @brief Server PK size. */
#define C_KTA__KS_S_PK_SIZE                          (64u)

/** @brief Field key salt. */
#define C_KTA__FIELD_KEY_SALT {0xEC, 0x15, 0x7C, 0x98, 0x04, 0x6D, 0xAD, 0x08, \
    0x25, 0x77, 0x2C, 0x52, 0x6F, 0x58, 0x1B, 0x05  \
  }

/** @brief Field key salt size. */
#define C_KTA__FIELD_KEY_SALT_SIZE                   (16u)

/**
 * @brief
 * Field key fixed info.
 * Replace segmentation seed provided by application at index 55 (16 bytes).
 */
#define C_KTA__FIELD_KEY_FIXED_INFO {0xa9, 0x4e, 0x61, 0x67, 0x72, 0x61, 0x76, 0x69, \
    0x73, 0x69, 0x6f, 0x6e, 0x54, 0x72, 0x75, 0x73, \
    0x74, 0x4d, 0x2d, 0x4f, 0x6e, 0x62, 0x6f, 0x61, \
    0x72, 0x64, 0x69, 0x6e, 0x67, 0x00, 0x4c, 0x30, \
    0x74, 0x6f, 0x4c, 0x31, 0x4b, 0x65, 0x79, 0x91, \
    0x6c, 0x75, 0x54, 0x80, 0x53, 0xbe, 0x4c, 0xc0, \
    0x91, 0x3f, 0x74, 0xc2, 0x1d, 0xff, 0x3f, 0x00, \
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, \
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, \
    0x41, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, \
    0x02, 0x01, 0x00  \
  }

/** @brief Field key fixed info size. */
#define C_KTA__FIELD_KEY_FIXED_INFO_SIZE             (83u)

/** @brief Input data for field enc key. */
#define C_KTA__FIELD_L2_ENC_INPUT_DATA {0xa9, 0x32, 0x30, 0x31, 0x38, 0x4e, 0x61, 0x67, \
    0x72, 0x61, 0x76, 0x69, 0x73, 0x69, 0x6f, 0x6e, \
    0x00, 0x4c, 0x31, 0x4b, 0x65, 0x79, 0x47, 0x65, \
    0x6e, 0x53, 0x75, 0x62, 0x4b, 0x65, 0x79, 0x31, \
    0x47, 0x43, 0x9d, 0xe8, 0x5e, 0x3a, 0x95, 0x04, \
    0x3d, 0xf3, 0x21, 0xb0, 0xf5, 0x4a, 0xd0, 0x20, \
    0x00, 0x32, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, \
    0x00, 0x00, 0x01, 0x00  \
  }

/** @brief Field enc key size. */
#define C_KTA__FIELD_L2_ENC_INPUT_DATA_SIZE          (60u)

/** @brief Input data for field auth key. */
#define C_KTA__FIELD_L2_AUTH_INPUT_DATA {0xa9, 0x32, 0x30, 0x31, 0x38, 0x4e, 0x61, 0x67, \
    0x72, 0x61, 0x76, 0x69, 0x73, 0x69, 0x6f, 0x6e, \
    0x00, 0x4c, 0x31, 0x4b, 0x65, 0x79, 0x47, 0x65, \
    0x6e, 0x53, 0x75, 0x62, 0x4b, 0x65, 0x79, 0xa7, \
    0x07, 0x0c, 0x3f, 0x25, 0x77, 0x25, 0xbc, 0xf1, \
    0x2f, 0x21, 0x42, 0x5f, 0xea, 0xca, 0x6e, 0x20, \
    0x06, 0x32, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, \
    0x00, 0x00, 0x01, 0x00  \
  }

/** @brief Field auth key size. */
#define C_KTA__FIELD_L2_AUTH_IN_DATA_SIZE         (60u)

/** @brief Rot Sol Id. */
#define C_KTA__ROT_SOL_ID {0x00, 0x17  \
  }

/** @brief Rot Sol Id size. */
#define C_KTA__ROT_SOL_ID_SIZE                       (2u)

/** @brief Position to start updating segmentation seed provided by application. */
#define C_KTA__FIELD_KEY_FIXED_INFO_L1SEGSEED_POS    (55u)

/** @brief Vendor specific maximum buffer size for icpp messages. */
#define C_K__ICPP_MSG_MAX_SIZE                       (1400u)

/** @brief Vendor specific chip certificate size. */
#define C_K__CHIP_CERT_MAX_SIZE_VENDOR_SPECIFIC      (1400u)

/** @brief Vendor specific command response size (Obj Mgnt). */
#define C_K__ICPP_CMD_RESPONSE_SIZE_VENDOR_SPECIFIC  (160u)

/** @brief Chip attestation certificate tag: E_K_ICPP_PARSER_FLD_TAG_CMD_PUBLIC_KEY. */
#define C_K__ICPP_FIELD_TAG_PUB_KEY_VENDOR_SPECIFIC  (0xF6u)

/* -------------------------------------------------------------------------- */
/* VARIABLES                                                                  */
/* -------------------------------------------------------------------------- */

/* -------------------------------------------------------------------------- */
/* FUNCTIONS                                                                  */
/* -------------------------------------------------------------------------- */

#endif // CRYPTOCONFIG_H

/* -------------------------------------------------------------------------- */
/* END OF FILE                                                                */
/* -------------------------------------------------------------------------- */
